@@ -9,6 +9,7 @@ Assets_Page::header (gettext ("Backup"));
 $smarty = new Smarty_Bibledit (__FILE__);
 
 $config_general = Database_Config_General::getInstance ();
+$database_logs = Database_Logs::getInstance ();
 
 if (isset($_POST['submit'])) {
   $name = $_POST['name'];
@@ -18,7 +19,8 @@ if (isset($_POST['submit'])) {
   if ($name == "") {
     $smarty->assign ("success", gettext ("Backups are disabled"));
   } else {
-    $smarty->assign ("success", gettext ("The filename was saved and the backup will be created soon"));
+    $smarty->assign ("success", gettext ("The filename was saved and the backup will be created within a minute"));
+    $database_logs->log (gettext ("Will create a backup within a minute"));
   }
 }
 
