@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -38,25 +38,6 @@ class Database_Books
     return self::$instance;
   }
 
-  public function verify () {
-    $database_instance = Database_Instance::getInstance();
-    $database_instance->runQuery ("DROP TABLE IF EXISTS books;");
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS books (
-sequence int auto_increment primary key,
-id int,
-english varchar(256),
-osis varchar(10),
-usfm varchar(3),
-bibleworks varchar(10),
-onlinebible varchar(10),
-type varchar(20),
-onechapter int
-);
-EOD;
-    $database_instance->runQuery ($str);
-  }
-
 
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
@@ -64,32 +45,6 @@ EOD;
   }
 
 
-  public function import ()
-  {
-    $database_instance = Database_Instance::getInstance();
-    include_once ("messages/messages.php");
-    message_information ("Importing book names");
-    $filename = "book/books.txt";
-    $data = file($filename, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES | FILE_TEXT);
-    foreach ($data as $line) {
-      $pos = strpos ($line, "#");
-      if ($pos !== false) continue;
-      $record = explode ("|", $line);
-      $id          = $record[0];
-      $english     = $record[1];
-      $osis        = $record[2];
-      $usfm        = $record[3];
-      $bibleworks  = $record[4];
-      $onlinebible = $record[5];
-      $type        = $record[6];
-      $onechapter  = 0;
-      if ($record[7] == "true") $onechapter = 1;
-      $query = "INSERT INTO books VALUES (NULL, $id, '$english', '$osis', '$usfm', '$bibleworks', '$onlinebible', '$type', $onechapter);";
-      $database_instance->runQuery ($query);
-    }
-  }
-
-
   public function getIDs ()
   {
     $database_instance = Database_Instance::getInstance();
@@ -149,6 +104,20 @@ EOD;
   }
 
 
+  public function getBibleworksFromId($id)
+  {
+    $database_instance = Database_Instance::getInstance();
+    $id = Database_SQLInjection::no ($id);
+    $query = "SELECT bibleworks FROM books WHERE id = $id;";
+    $result = $database_instance->runQuery ($query);
+    if ($result->num_rows == 0) {
+      return gettext ("Xxx");
+    }
+    $row = $result->fetch_row ();
+    return $row[0];
+  }
+
+
   public function getIdFromUsfm($usfm)
   {
     $database_instance = Database_Instance::getInstance();
