@@ -19,25 +19,14 @@ class Database_Config_General
 
 
   /**
-  * Verify database table, optionally creating and/or optimizing it
+  * Optimize database table
   */
-  public function verify () {
-    $database_instance = Database_Instance::getInstance();
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS config_general (
-ident VARCHAR(100) NOT NULL,
-value VARCHAR(1000),
-offset INT NOT NULL
-);
-EOD;
-    $database_instance->runQuery ($str);
-  }
-
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE config_general;");
   }
 
+
   // Functions that retrieve the value or list from the database.
   private function getValue ($key, $default) {
     $database = Database_Instance::getInstance ();
@@ -186,13 +175,6 @@ EOD;
     $this->setValue ("timer-five-minutes", $value);
   }   
 
-  public function getTimerDay() {
-    return $this->getValue ("timer-day", "");
-  }
-  public function setTimerDay ($value) {
-    $this->setValue ("timer-day", $value);
-  }   
-
   public function getPublicSshKey() {
     return $this->getValue ("public-ssh-key", "");
   }
