@@ -1,8 +1,6 @@
 <?php
 
 
-
-
 class Database_Logs
 {
   /**
@@ -21,27 +19,14 @@ class Database_Logs
 
 
   /**
-  * verify - Verifies the database table
+  * Optimizes the table.
   */
-  public function verify () {
-    $database_instance = Database_Instance::getInstance();
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS logs (
-id int auto_increment primary key,
-timestamp int,
-event text
-);
-EOD;
-    $database_instance->runQuery ($str);
-    $database_instance->runQuery ("ALTER TABLE logs ADD level int AFTER timestamp;");
-  }
-
-
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE logs;");
   }
 
+
   /**
   * log - Logs entry
   * $manager - whether this logbook entry should be visible to the Manager as well.
@@ -99,7 +84,7 @@ EOD;
     $result  = $server->runQuery ($query);
     $count = $result->fetch_row ();
     $count = $count[0];
-    $amount = 20;
+    $amount = 60;
     $limit = $count - ($page * $amount);
     if ($limit < 0) {
       $amount = $amount + $limit;
