@@ -23,24 +23,8 @@ class Database_Mail
 
 
   /**
-  * verify - Verifies the database table
+  * Optimizes the database table
   */
-  public function verify () {
-    $database_instance = Database_Instance::getInstance();
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS mail (
-id int auto_increment primary key,
-username varchar(256),
-timestamp int,
-label varchar(30),
-subject varchar(256),
-body text
-);
-EOD;
-    $database_instance->runQuery ($str);
-  }
-
-
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE mail;");
