@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -38,12 +38,6 @@ class Database_Mailer
     return self::$instance;
   }
 
-  public function verify () {
-    $query = "CREATE TABLE IF NOT EXISTS mailer (id int, retry int, delay int);";
-    $database_instance = Database_Instance::getInstance();
-    $database_instance->runQuery ($query);
-  }
-
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE mailer;");
