@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -39,30 +39,6 @@ class Database_Versifications
   }
 
 
-  public function verify () {
-    $database_instance = Database_Instance::getInstance();
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS versification_names (
-system int primary key,
-name varchar(256)
-);
-EOD;
-    $database_instance->runQuery ($str);
-    $database_instance->runQuery ("OPTIMIZE TABLE versification_names;");
-$str = <<<EOD
-CREATE TABLE IF NOT EXISTS versification_data (
-id int auto_increment primary key,
-system int,
-book int,
-chapter int,
-verse int
-);
-EOD;
-    $database_instance->runQuery ($str);
-    $database_instance->runQuery ("OPTIMIZE TABLE versification_data;");
-  }
-
-
   public function optimize () {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("OPTIMIZE TABLE versification_names;");
@@ -70,26 +46,6 @@ EOD;
   }
 
 
-  public function import ()
-  {
-    include_once ("messages/messages.php");    
-    message_information ("Importing versification systems:");
-    $directory = "versification";
-    $handler = opendir($directory);
-    while ($file = readdir($handler)) {
-      $pieces = explode (".", $file);
-      if ($pieces[1] == "xml") {
-        $file = "$directory/$file";
-        message_information ("- $pieces[0]");
-        flush ();
-        $contents = file_get_contents ($file);
-        $this->importBibleditXml ($contents, $pieces[0]);
-      }
-    }
-    closedir($handler);
-  }
-
-
   public function importBibleditXml ($contents, $name)
   {
     // Delete old system if it is there, and create new one.
@@ -177,7 +133,7 @@ EOD;
     if ($id > 0) {
       return $id;
     }   
-    // Get the first free ID.
+    // Get the first free ID starting from 1000.
     $database_instance = Database_Instance::getInstance();
     $query = "SELECT system FROM versification_names ORDER BY system DESC LIMIT 1;";
     $result = $database_instance->runQuery ($query);
@@ -187,6 +143,7 @@ EOD;
       $id = $row[0];
     }
     $id++;
+    if ($id < 1000) $id = 1000;
     // Create the empty system.
     $name = Database_SQLInjection::no ($name);
     $query = "INSERT INTO versification_names VALUES ($id, '$name');";
