@@ -1,8 +1,10 @@
 <?php
 
+
 class Filter_Diff
 {
 
+
   /**
   * This filter produces USFM and html files to be used for showing the differences between them.
   * The files contain all verses that differ.
@@ -74,10 +76,10 @@ class Filter_Diff
     $newfile = escapeshellarg ($newfile);
     $outputfile = escapeshellarg ($outputfile);
     $command = "wdiff --start-insert='<span style=\"font-weight: bold;\">' --end-insert='</span>' --start-delete='<span style=\"text-decoration: line-through;\">' --end-delete='</span>' $oldfile $newfile > $outputfile 2>&1";
-    $database_logs->log ($command, true);
+    $database_logs->log ("changes: $command", true);
     exec ($command, $output, &$return_var);
     foreach ($output as $line) {
-      $database_logs->log ($line, true);
+      $database_logs->log ("changes: $line", true);
     }
   }
 
