@@ -6,7 +6,9 @@ $smarty = new Smarty_Bibledit (__FILE__);
 if (isset($_GET['run'])) {
   $database_config_general = Database_Config_General::getInstance();
   $database_config_general->setTimerSendReceive (time ());
-  $smarty->assign ("success", gettext ("Will send and receive Bibles soon. See the logbook for progress."));
+  $smarty->assign ("success", gettext ("Will send and receive Bibles within a minute. See the logbook for progress."));
+  $database_logs = Database_Logs::getInstance ();
+  $database_logs->log (gettext ("Will send and receive Bibles within a minute"));
 }
 $smarty->display("sendreceive.tpl");
 Assets_Page::footer ();
