@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -44,32 +44,30 @@ set_time_limit(0);
 register_shutdown_function('shutdown');
 
 
-$crontable = Database_Cron::getInstance ();
 $log = Database_Logs::getInstance();
 $config_general = Database_Config_General::getInstance ();
 //$processUser = posix_getpwuid(posix_geteuid());
 //$processUser = $processUser['name'];
-//$log->log ("cron run by user $processUser", false);
-//$log->log ("Minutely timer", false);
 
 
 $current_timestamp = time ();
 
 
-$previous_timestamp = $config_general->getTimerMinute ();
-// Notice when the mysql database is down. 
-// Without this it will spawn many shell processes that effectively hang the system.
-$database_down = $previous_timestamp === "";
+// CPU-intensive actions run at midnight.
+// The advantage of this is that while the site is in use during the day, 
+// CPU-intensive actions do not slow down the site.
+// There have been cases that somebody submitted a comment to a consultation note, 
+// but since the site didn't respond fast enough, 
+// the person kept pressing the submit button,
+// with the result that the comment was added multiple times to the note.
+$midnight = (date ('Gi') == 0);
 
-  
-// Tasks to be done once a minute:
 
-// Mailer.
+
+// Mailer is done once a minute.
 $timer_mailer = new Timer_Mailer ();
 $timer_mailer->run ();
 unset ($timer_mailer);
-  
-
 
 
 $previous_timestamp = $config_general->getTimerFiveMinutes ();
@@ -85,25 +83,15 @@ if ($current_timestamp >= ($previous_timestamp + 300)) {
 }
 
 
-$previous_timestamp = $config_general->getTimerDay ();
-if ($current_timestamp >= ($previous_timestamp + 86400)) {
-  $config_general->setTimerDay ($current_timestamp);
-  
-  // Tasks to be done once a day:
-
-  // Trim databases.
+// Trim databases at midnight.
+if ($midnight) {
   $workingdirectory = dirname (__FILE__);
-  if (!$database_down) shell_exec ("cd $workingdirectory; php trimdatabases.php > /dev/null 2>&1 &");
-
-  // Log memory usage.    
-  $memory_usage = memory_get_usage();
-  $log->log ("Memory usage is $memory_usage bytes");
-  
+  shell_exec ("cd $workingdirectory; php trimdatabases.php > /dev/null 2>&1 &");
 }
 
 
 $backup_timestamp = $config_general->getTimerBackup ();
-if ($current_timestamp >= $backup_timestamp) {
+if (($current_timestamp >= $backup_timestamp) || $midnight) {
   $backup_timestamp += 86400;
   while ($current_timestamp >= $backup_timestamp) {
     // This loop updates the backup timestamp to a value larger than the current time.
@@ -112,13 +100,13 @@ if ($current_timestamp >= $backup_timestamp) {
   }
   $config_general->setTimerBackup ($backup_timestamp);
   $workingdirectory = dirname (__FILE__);
-  if (!$database_down) shell_exec ("cd $workingdirectory; php backup.php > /dev/null 2>&1 &");
+  shell_exec ("cd $workingdirectory; php backup.php > /dev/null 2>&1 &");
 }
 unset ($backup_timestamp);
 
 
 $diff_timestamp = $config_general->getTimerDiff ();
-if ($current_timestamp >= $diff_timestamp) {
+if (($current_timestamp >= $diff_timestamp) || $midnight) {
   $diff_timestamp += 86400;
   while ($current_timestamp >= $diff_timestamp) {
     // This loop updates the timestamp to a value larger than the current time.
@@ -127,13 +115,13 @@ if ($current_timestamp >= $diff_timestamp) {
   }
   $config_general->setTimerDiff ($diff_timestamp);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
-  if (!$database_down) shell_exec ("cd $workingdirectory; php changes.php > /dev/null 2>&1 &");
+  shell_exec ("cd $workingdirectory; php changes.php > /dev/null 2>&1 &");
 }
 unset ($diff_timestamp);
 
 
 $exports_timestamp = $config_general->getTimerExports ();
-if ($current_timestamp >= $exports_timestamp) {
+if (($current_timestamp >= $exports_timestamp) || $midnight) {
   $exports_timestamp += 86400;
   while ($current_timestamp >= $exports_timestamp) {
     // This loop updates the timestamp to a value larger than the current time.
@@ -142,13 +130,13 @@ if ($current_timestamp >= $exports_timestamp) {
   }
   $config_general->setTimerExports ($exports_timestamp);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
-  if (!$database_down) shell_exec ("cd $workingdirectory; php exports.php > /dev/null 2>&1 &");
+  shell_exec ("cd $workingdirectory; php exports.php > /dev/null 2>&1 &");
 }
 unset ($exports_timestamp);
 
 
 $sendreceive_timestamp = $config_general->getTimerSendReceive ();
-if ($current_timestamp >= $sendreceive_timestamp) {
+if (($current_timestamp >= $sendreceive_timestamp) || $midnight) {
   $sendreceive_timestamp += 86400;
   while ($current_timestamp >= $sendreceive_timestamp) {
     // This loop updates the timestamp to a value larger than the current time.
@@ -157,7 +145,7 @@ if ($current_timestamp >= $sendreceive_timestamp) {
   }
   $config_general->setTimerSendReceive ($sendreceive_timestamp);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
-  if (!$database_down) shell_exec ("cd $workingdirectory; php sendreceive.php > /dev/null 2>&1 &");
+  shell_exec ("cd $workingdirectory; php sendreceive.php > /dev/null 2>&1 &");
 }
 unset ($sendreceive_timestamp);
 
